pub enum VarFamilyError {
TypeError {
family_name: String,
requested_type: String,
actual_type: String,
},
UnknownFamily {
family_name: String,
},
}Expand description
Errors that can occur when working with variable families
Variants
TypeError
Tried to retrieve a variable family as the wrong type
Fields
UnknownFamily
Variable family not found in collection